@@ -14,10 +14,17 @@ use Lemonldap::NG::Common::Conf::Constants; #inherits
 *EXPORT_TAGS = *Lemonldap::NG::Portal::Simple::EXPORT_TAGS;
 *EXPORT      = *Lemonldap::NG::Portal::Simple::EXPORT;
 
-our $VERSION = '0.992';
+our $VERSION = '1.0.0';
 use base qw(Lemonldap::NG::Portal::Simple);
 our $confCached;
 
+BEGIN {
+    eval {
+        require threads::shared;
+        threads::shared::share($confCached);
+    };
+}
+
 ##################
 # OVERLOADED SUB #
 ##################
@@ -186,7 +193,7 @@ Same as L<Lemonldap::NG::Portal::Simple>.
 
 L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Portal::SharedConf>,
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Manager>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -196,7 +203,7 @@ Thomas Chemineau, E<lt>thomas.chemineau@linagora.comE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -209,7 +216,7 @@ Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt> and
 Thomas Chemineau, E<lt>thomas.chemineau@linagora.comE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
