@@ -7,8 +7,9 @@ package Lemonldap::NG::Portal::UserDBDBI;
 
 use strict;
 use Lemonldap::NG::Portal::Simple;
+use Lemonldap::NG::Portal::_DBI; #inherits
 
-our $VERSION = '0.992';
+our $VERSION = '1.0.0';
 
 ## @apmethod int userDBInit()
 # Set default values
